@@ -34,7 +34,7 @@ pub const INSTRUCTION_TRANSFER_WITH_CROSS:u8=31;
 pub const INSTRUCTION_UPDATE_SPLU_TURING_MASHINE:u8=32;
 pub const INSTRUCTION_UPDATE_STATE_PPU:u8=33;
 pub const INSTRUCTION_RESET_SPLU_TERTIARY_PPU:u8=34;
-pub const INSTRUCTION_UPDATE_SPLU_TERTIARY_PPU:u8=35;
+pub const INSTRUCTION_ADD_SPLU_TERTIARY_PPU:u8=35;
 pub const INSTRUCTION_TRANSFER_REWARDS:u8=36;
 pub const INSTRUCTION_CREATE_INIT_TURING_MASHINE:u8=38;
 pub const INSTRUCTION_CLOSE_TURING_MASHINE:u8=39;
